from collections.abc import Callable
from typing import Any, Type

import playwright.async_api
import playwright.sync_api
from opentelemetry.util.types import AttributeValue

AttrConstructor = Callable[[Any], AttributeValue]

# Note: This part is generated by tests/test_targets.py. Do not edit it manually.
# START:METHODS
METHODS: dict[Type, tuple[tuple[str, dict[str, AttrConstructor]], ...]] = {
    playwright.async_api.BrowserType: (
        (
            "connect",
            {
                "expose_network": str,
                "slow_mo": float,
                "timeout": float,
                "ws_endpoint": str,
            },
        ),
        (
            "connect_over_cdp",
            {
                "endpoint_url": str,
                "slow_mo": float,
                "timeout": float,
            },
        ),
        (
            "launch",
            {
                "channel": str,
                "chromium_sandbox": bool,
                "devtools": bool,
                "downloads_path": str,
                "executable_path": str,
                "handle_sighup": bool,
                "handle_sigint": bool,
                "handle_sigterm": bool,
                "headless": bool,
                "ignore_default_args": bool,
                "slow_mo": float,
                "timeout": float,
                "traces_dir": str,
            },
        ),
        (
            "launch_persistent_context",
            {
                "accept_downloads": bool,
                "base_url": str,
                "bypass_csp": bool,
                "channel": str,
                "chromium_sandbox": bool,
                "device_scale_factor": float,
                "devtools": bool,
                "downloads_path": str,
                "executable_path": str,
                "handle_sighup": bool,
                "handle_sigint": bool,
                "handle_sigterm": bool,
                "has_touch": bool,
                "headless": bool,
                "ignore_default_args": bool,
                "ignore_https_errors": bool,
                "is_mobile": bool,
                "java_script_enabled": bool,
                "locale": str,
                "no_viewport": bool,
                "offline": bool,
                "record_har_omit_content": bool,
                "record_har_path": str,
                "record_har_url_filter": str,
                "record_video_dir": str,
                "slow_mo": float,
                "strict_selectors": bool,
                "timeout": float,
                "timezone_id": str,
                "traces_dir": str,
                "user_agent": str,
                "user_data_dir": str,
            },
        ),
    ),
    playwright.async_api.Page: (
        (
            "add_init_script",
            {
                "path": str,
                "script": str,
            },
        ),
        (
            "add_locator_handler",
            {
                "no_wait_after": bool,
                "times": int,
            },
        ),
        (
            "add_script_tag",
            {
                "content": str,
                "path": str,
                "type": str,
                "url": str,
            },
        ),
        (
            "add_style_tag",
            {
                "content": str,
                "path": str,
                "url": str,
            },
        ),
        ("bring_to_front", {}),
        (
            "check",
            {
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "click",
            {
                "click_count": int,
                "delay": float,
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "close",
            {
                "reason": str,
                "run_before_unload": bool,
            },
        ),
        ("content", {}),
        (
            "dblclick",
            {
                "delay": float,
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "dispatch_event",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
                "type": str,
            },
        ),
        (
            "drag_and_drop",
            {
                "force": bool,
                "no_wait_after": bool,
                "source": str,
                "strict": bool,
                "target": str,
                "timeout": float,
                "trial": bool,
            },
        ),
        ("emulate_media", {}),
        (
            "eval_on_selector",
            {
                "expression": str,
                "selector": str,
                "strict": bool,
            },
        ),
        (
            "eval_on_selector_all",
            {
                "expression": str,
                "selector": str,
            },
        ),
        (
            "evaluate",
            {
                "expression": str,
            },
        ),
        (
            "evaluate_handle",
            {
                "expression": str,
            },
        ),
        (
            "expose_binding",
            {
                "handle": bool,
                "name": str,
            },
        ),
        (
            "expose_function",
            {
                "name": str,
            },
        ),
        (
            "fill",
            {
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "value": str,
            },
        ),
        (
            "focus",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "get_attribute",
            {
                "name": str,
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "go_back",
            {
                "timeout": float,
            },
        ),
        (
            "go_forward",
            {
                "timeout": float,
            },
        ),
        (
            "goto",
            {
                "referer": str,
                "timeout": float,
                "url": str,
            },
        ),
        (
            "hover",
            {
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "inner_html",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "inner_text",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "input_value",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "is_checked",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "is_disabled",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "is_editable",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "is_enabled",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "is_hidden",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "is_visible",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        ("opener", {}),
        ("pause", {}),
        (
            "pdf",
            {
                "display_header_footer": bool,
                "footer_template": str,
                "format": str,
                "header_template": str,
                "landscape": bool,
                "outline": bool,
                "page_ranges": str,
                "path": str,
                "prefer_css_page_size": bool,
                "print_background": bool,
                "scale": float,
                "tagged": bool,
            },
        ),
        (
            "press",
            {
                "delay": float,
                "key": str,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "query_selector",
            {
                "selector": str,
                "strict": bool,
            },
        ),
        (
            "query_selector_all",
            {
                "selector": str,
            },
        ),
        (
            "reload",
            {
                "timeout": float,
            },
        ),
        ("remove_locator_handler", {}),
        ("request_gc", {}),
        (
            "route",
            {
                "times": int,
                "url": str,
            },
        ),
        (
            "route_from_har",
            {
                "har": str,
                "update": bool,
                "url": str,
            },
        ),
        (
            "route_web_socket",
            {
                "url": str,
            },
        ),
        (
            "screenshot",
            {
                "full_page": bool,
                "mask_color": str,
                "omit_background": bool,
                "path": str,
                "quality": int,
                "style": str,
                "timeout": float,
            },
        ),
        (
            "select_option",
            {
                "force": bool,
                "index": int,
                "label": str,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "value": str,
            },
        ),
        (
            "set_checked",
            {
                "checked": bool,
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "set_content",
            {
                "html": str,
                "timeout": float,
            },
        ),
        ("set_extra_http_headers", {}),
        (
            "set_input_files",
            {
                "files": str,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        ("set_viewport_size", {}),
        (
            "tap",
            {
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "text_content",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        ("title", {}),
        (
            "type",
            {
                "delay": float,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "text": str,
                "timeout": float,
            },
        ),
        (
            "uncheck",
            {
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "unroute",
            {
                "url": str,
            },
        ),
        ("unroute_all", {}),
        (
            "wait_for_event",
            {
                "event": str,
                "timeout": float,
            },
        ),
        (
            "wait_for_function",
            {
                "expression": str,
                "polling": float,
                "timeout": float,
            },
        ),
        (
            "wait_for_load_state",
            {
                "timeout": float,
            },
        ),
        (
            "wait_for_selector",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "wait_for_timeout",
            {
                "timeout": float,
            },
        ),
        (
            "wait_for_url",
            {
                "timeout": float,
                "url": str,
            },
        ),
    ),
    playwright.async_api.Browser: (
        (
            "close",
            {
                "reason": str,
            },
        ),
        ("new_browser_cdp_session", {}),
        (
            "new_context",
            {
                "accept_downloads": bool,
                "base_url": str,
                "bypass_csp": bool,
                "default_browser_type": str,
                "device_scale_factor": float,
                "has_touch": bool,
                "ignore_https_errors": bool,
                "is_mobile": bool,
                "java_script_enabled": bool,
                "locale": str,
                "no_viewport": bool,
                "offline": bool,
                "record_har_omit_content": bool,
                "record_har_path": str,
                "record_har_url_filter": str,
                "record_video_dir": str,
                "storage_state": str,
                "strict_selectors": bool,
                "timezone_id": str,
                "user_agent": str,
            },
        ),
        (
            "new_page",
            {
                "accept_downloads": bool,
                "base_url": str,
                "bypass_csp": bool,
                "default_browser_type": str,
                "device_scale_factor": float,
                "has_touch": bool,
                "ignore_https_errors": bool,
                "is_mobile": bool,
                "java_script_enabled": bool,
                "locale": str,
                "no_viewport": bool,
                "offline": bool,
                "record_har_omit_content": bool,
                "record_har_path": str,
                "record_har_url_filter": str,
                "record_video_dir": str,
                "storage_state": str,
                "strict_selectors": bool,
                "timezone_id": str,
                "user_agent": str,
            },
        ),
        (
            "start_tracing",
            {
                "path": str,
                "screenshots": bool,
            },
        ),
        ("stop_tracing", {}),
    ),
    playwright.async_api.Frame: (
        (
            "add_script_tag",
            {
                "content": str,
                "path": str,
                "type": str,
                "url": str,
            },
        ),
        (
            "add_style_tag",
            {
                "content": str,
                "path": str,
                "url": str,
            },
        ),
        (
            "check",
            {
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "click",
            {
                "click_count": int,
                "delay": float,
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        ("content", {}),
        (
            "dblclick",
            {
                "delay": float,
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "dispatch_event",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
                "type": str,
            },
        ),
        (
            "drag_and_drop",
            {
                "force": bool,
                "no_wait_after": bool,
                "source": str,
                "strict": bool,
                "target": str,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "eval_on_selector",
            {
                "expression": str,
                "selector": str,
                "strict": bool,
            },
        ),
        (
            "eval_on_selector_all",
            {
                "expression": str,
                "selector": str,
            },
        ),
        (
            "evaluate",
            {
                "expression": str,
            },
        ),
        (
            "evaluate_handle",
            {
                "expression": str,
            },
        ),
        (
            "fill",
            {
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "value": str,
            },
        ),
        (
            "focus",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        ("frame_element", {}),
        (
            "get_attribute",
            {
                "name": str,
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "goto",
            {
                "referer": str,
                "timeout": float,
                "url": str,
            },
        ),
        (
            "hover",
            {
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "inner_html",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "inner_text",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "input_value",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "is_checked",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "is_disabled",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "is_editable",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "is_enabled",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "is_hidden",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "is_visible",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "press",
            {
                "delay": float,
                "key": str,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "query_selector",
            {
                "selector": str,
                "strict": bool,
            },
        ),
        (
            "query_selector_all",
            {
                "selector": str,
            },
        ),
        (
            "select_option",
            {
                "force": bool,
                "index": int,
                "label": str,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "value": str,
            },
        ),
        (
            "set_checked",
            {
                "checked": bool,
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "set_content",
            {
                "html": str,
                "timeout": float,
            },
        ),
        (
            "set_input_files",
            {
                "files": str,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "tap",
            {
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "text_content",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        ("title", {}),
        (
            "type",
            {
                "delay": float,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "text": str,
                "timeout": float,
            },
        ),
        (
            "uncheck",
            {
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "wait_for_function",
            {
                "expression": str,
                "polling": float,
                "timeout": float,
            },
        ),
        (
            "wait_for_load_state",
            {
                "timeout": float,
            },
        ),
        (
            "wait_for_selector",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "wait_for_timeout",
            {
                "timeout": float,
            },
        ),
        (
            "wait_for_url",
            {
                "timeout": float,
                "url": str,
            },
        ),
    ),
    playwright.async_api.ElementHandle: (
        ("bounding_box", {}),
        (
            "check",
            {
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "click",
            {
                "click_count": int,
                "delay": float,
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        ("content_frame", {}),
        (
            "dblclick",
            {
                "delay": float,
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "dispatch_event",
            {
                "type": str,
            },
        ),
        ("dispose", {}),
        (
            "eval_on_selector",
            {
                "expression": str,
                "selector": str,
            },
        ),
        (
            "eval_on_selector_all",
            {
                "expression": str,
                "selector": str,
            },
        ),
        (
            "evaluate",
            {
                "expression": str,
            },
        ),
        (
            "evaluate_handle",
            {
                "expression": str,
            },
        ),
        (
            "fill",
            {
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "value": str,
            },
        ),
        ("focus", {}),
        (
            "get_attribute",
            {
                "name": str,
            },
        ),
        ("get_properties", {}),
        (
            "get_property",
            {
                "property_name": str,
            },
        ),
        (
            "hover",
            {
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        ("inner_html", {}),
        ("inner_text", {}),
        (
            "input_value",
            {
                "timeout": float,
            },
        ),
        ("is_checked", {}),
        ("is_disabled", {}),
        ("is_editable", {}),
        ("is_enabled", {}),
        ("is_hidden", {}),
        ("is_visible", {}),
        ("json_value", {}),
        ("owner_frame", {}),
        (
            "press",
            {
                "delay": float,
                "key": str,
                "no_wait_after": bool,
                "timeout": float,
            },
        ),
        (
            "query_selector",
            {
                "selector": str,
            },
        ),
        (
            "query_selector_all",
            {
                "selector": str,
            },
        ),
        (
            "screenshot",
            {
                "mask_color": str,
                "omit_background": bool,
                "path": str,
                "quality": int,
                "style": str,
                "timeout": float,
            },
        ),
        (
            "scroll_into_view_if_needed",
            {
                "timeout": float,
            },
        ),
        (
            "select_option",
            {
                "force": bool,
                "index": int,
                "label": str,
                "no_wait_after": bool,
                "timeout": float,
                "value": str,
            },
        ),
        (
            "select_text",
            {
                "force": bool,
                "timeout": float,
            },
        ),
        (
            "set_checked",
            {
                "checked": bool,
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "set_input_files",
            {
                "files": str,
                "no_wait_after": bool,
                "timeout": float,
            },
        ),
        (
            "tap",
            {
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        ("text_content", {}),
        (
            "type",
            {
                "delay": float,
                "no_wait_after": bool,
                "text": str,
                "timeout": float,
            },
        ),
        (
            "uncheck",
            {
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "wait_for_element_state",
            {
                "timeout": float,
            },
        ),
        (
            "wait_for_selector",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
    ),
    playwright.async_api.Locator: (
        ("all", {}),
        ("all_inner_texts", {}),
        ("all_text_contents", {}),
        (
            "aria_snapshot",
            {
                "ref": bool,
                "timeout": float,
            },
        ),
        (
            "blur",
            {
                "timeout": float,
            },
        ),
        (
            "bounding_box",
            {
                "timeout": float,
            },
        ),
        (
            "check",
            {
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "clear",
            {
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
            },
        ),
        (
            "click",
            {
                "click_count": int,
                "delay": float,
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        ("count", {}),
        (
            "dblclick",
            {
                "delay": float,
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "dispatch_event",
            {
                "timeout": float,
                "type": str,
            },
        ),
        (
            "drag_to",
            {
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "element_handle",
            {
                "timeout": float,
            },
        ),
        ("element_handles", {}),
        (
            "evaluate",
            {
                "expression": str,
                "timeout": float,
            },
        ),
        (
            "evaluate_all",
            {
                "expression": str,
            },
        ),
        (
            "evaluate_handle",
            {
                "expression": str,
                "timeout": float,
            },
        ),
        (
            "fill",
            {
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "value": str,
            },
        ),
        (
            "focus",
            {
                "timeout": float,
            },
        ),
        (
            "get_attribute",
            {
                "name": str,
                "timeout": float,
            },
        ),
        ("highlight", {}),
        (
            "hover",
            {
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "inner_html",
            {
                "timeout": float,
            },
        ),
        (
            "inner_text",
            {
                "timeout": float,
            },
        ),
        (
            "input_value",
            {
                "timeout": float,
            },
        ),
        (
            "is_checked",
            {
                "timeout": float,
            },
        ),
        (
            "is_disabled",
            {
                "timeout": float,
            },
        ),
        (
            "is_editable",
            {
                "timeout": float,
            },
        ),
        (
            "is_enabled",
            {
                "timeout": float,
            },
        ),
        (
            "is_hidden",
            {
                "timeout": float,
            },
        ),
        (
            "is_visible",
            {
                "timeout": float,
            },
        ),
        (
            "press",
            {
                "delay": float,
                "key": str,
                "no_wait_after": bool,
                "timeout": float,
            },
        ),
        (
            "press_sequentially",
            {
                "delay": float,
                "no_wait_after": bool,
                "text": str,
                "timeout": float,
            },
        ),
        (
            "screenshot",
            {
                "mask_color": str,
                "omit_background": bool,
                "path": str,
                "quality": int,
                "style": str,
                "timeout": float,
            },
        ),
        (
            "scroll_into_view_if_needed",
            {
                "timeout": float,
            },
        ),
        (
            "select_option",
            {
                "force": bool,
                "index": int,
                "label": str,
                "no_wait_after": bool,
                "timeout": float,
                "value": str,
            },
        ),
        (
            "select_text",
            {
                "force": bool,
                "timeout": float,
            },
        ),
        (
            "set_checked",
            {
                "checked": bool,
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "set_input_files",
            {
                "files": str,
                "no_wait_after": bool,
                "timeout": float,
            },
        ),
        (
            "tap",
            {
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "text_content",
            {
                "timeout": float,
            },
        ),
        (
            "type",
            {
                "delay": float,
                "no_wait_after": bool,
                "text": str,
                "timeout": float,
            },
        ),
        (
            "uncheck",
            {
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "wait_for",
            {
                "timeout": float,
            },
        ),
    ),
    playwright.sync_api.BrowserType: (
        (
            "connect",
            {
                "expose_network": str,
                "slow_mo": float,
                "timeout": float,
                "ws_endpoint": str,
            },
        ),
        (
            "connect_over_cdp",
            {
                "endpoint_url": str,
                "slow_mo": float,
                "timeout": float,
            },
        ),
        (
            "launch",
            {
                "channel": str,
                "chromium_sandbox": bool,
                "devtools": bool,
                "downloads_path": str,
                "executable_path": str,
                "handle_sighup": bool,
                "handle_sigint": bool,
                "handle_sigterm": bool,
                "headless": bool,
                "ignore_default_args": bool,
                "slow_mo": float,
                "timeout": float,
                "traces_dir": str,
            },
        ),
        (
            "launch_persistent_context",
            {
                "accept_downloads": bool,
                "base_url": str,
                "bypass_csp": bool,
                "channel": str,
                "chromium_sandbox": bool,
                "device_scale_factor": float,
                "devtools": bool,
                "downloads_path": str,
                "executable_path": str,
                "handle_sighup": bool,
                "handle_sigint": bool,
                "handle_sigterm": bool,
                "has_touch": bool,
                "headless": bool,
                "ignore_default_args": bool,
                "ignore_https_errors": bool,
                "is_mobile": bool,
                "java_script_enabled": bool,
                "locale": str,
                "no_viewport": bool,
                "offline": bool,
                "record_har_omit_content": bool,
                "record_har_path": str,
                "record_har_url_filter": str,
                "record_video_dir": str,
                "slow_mo": float,
                "strict_selectors": bool,
                "timeout": float,
                "timezone_id": str,
                "traces_dir": str,
                "user_agent": str,
                "user_data_dir": str,
            },
        ),
    ),
    playwright.sync_api.Page: (
        (
            "add_init_script",
            {
                "path": str,
                "script": str,
            },
        ),
        (
            "add_locator_handler",
            {
                "no_wait_after": bool,
                "times": int,
            },
        ),
        (
            "add_script_tag",
            {
                "content": str,
                "path": str,
                "type": str,
                "url": str,
            },
        ),
        (
            "add_style_tag",
            {
                "content": str,
                "path": str,
                "url": str,
            },
        ),
        ("bring_to_front", {}),
        (
            "check",
            {
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "click",
            {
                "click_count": int,
                "delay": float,
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "close",
            {
                "reason": str,
                "run_before_unload": bool,
            },
        ),
        ("content", {}),
        (
            "dblclick",
            {
                "delay": float,
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "dispatch_event",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
                "type": str,
            },
        ),
        (
            "drag_and_drop",
            {
                "force": bool,
                "no_wait_after": bool,
                "source": str,
                "strict": bool,
                "target": str,
                "timeout": float,
                "trial": bool,
            },
        ),
        ("emulate_media", {}),
        (
            "eval_on_selector",
            {
                "expression": str,
                "selector": str,
                "strict": bool,
            },
        ),
        (
            "eval_on_selector_all",
            {
                "expression": str,
                "selector": str,
            },
        ),
        (
            "evaluate",
            {
                "expression": str,
            },
        ),
        (
            "evaluate_handle",
            {
                "expression": str,
            },
        ),
        (
            "expose_binding",
            {
                "handle": bool,
                "name": str,
            },
        ),
        (
            "expose_function",
            {
                "name": str,
            },
        ),
        (
            "fill",
            {
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "value": str,
            },
        ),
        (
            "focus",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "get_attribute",
            {
                "name": str,
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "go_back",
            {
                "timeout": float,
            },
        ),
        (
            "go_forward",
            {
                "timeout": float,
            },
        ),
        (
            "goto",
            {
                "referer": str,
                "timeout": float,
                "url": str,
            },
        ),
        (
            "hover",
            {
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "inner_html",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "inner_text",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "input_value",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "is_checked",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "is_disabled",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "is_editable",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "is_enabled",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "is_hidden",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "is_visible",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        ("opener", {}),
        ("pause", {}),
        (
            "pdf",
            {
                "display_header_footer": bool,
                "footer_template": str,
                "format": str,
                "header_template": str,
                "landscape": bool,
                "outline": bool,
                "page_ranges": str,
                "path": str,
                "prefer_css_page_size": bool,
                "print_background": bool,
                "scale": float,
                "tagged": bool,
            },
        ),
        (
            "press",
            {
                "delay": float,
                "key": str,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "query_selector",
            {
                "selector": str,
                "strict": bool,
            },
        ),
        (
            "query_selector_all",
            {
                "selector": str,
            },
        ),
        (
            "reload",
            {
                "timeout": float,
            },
        ),
        ("remove_locator_handler", {}),
        ("request_gc", {}),
        (
            "route",
            {
                "times": int,
                "url": str,
            },
        ),
        (
            "route_from_har",
            {
                "har": str,
                "update": bool,
                "url": str,
            },
        ),
        (
            "route_web_socket",
            {
                "url": str,
            },
        ),
        (
            "screenshot",
            {
                "full_page": bool,
                "mask_color": str,
                "omit_background": bool,
                "path": str,
                "quality": int,
                "style": str,
                "timeout": float,
            },
        ),
        (
            "select_option",
            {
                "force": bool,
                "index": int,
                "label": str,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "value": str,
            },
        ),
        (
            "set_checked",
            {
                "checked": bool,
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "set_content",
            {
                "html": str,
                "timeout": float,
            },
        ),
        ("set_extra_http_headers", {}),
        (
            "set_input_files",
            {
                "files": str,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        ("set_viewport_size", {}),
        (
            "tap",
            {
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "text_content",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        ("title", {}),
        (
            "type",
            {
                "delay": float,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "text": str,
                "timeout": float,
            },
        ),
        (
            "uncheck",
            {
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "unroute",
            {
                "url": str,
            },
        ),
        ("unroute_all", {}),
        (
            "wait_for_event",
            {
                "event": str,
                "timeout": float,
            },
        ),
        (
            "wait_for_function",
            {
                "expression": str,
                "polling": float,
                "timeout": float,
            },
        ),
        (
            "wait_for_load_state",
            {
                "timeout": float,
            },
        ),
        (
            "wait_for_selector",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "wait_for_timeout",
            {
                "timeout": float,
            },
        ),
        (
            "wait_for_url",
            {
                "timeout": float,
                "url": str,
            },
        ),
    ),
    playwright.sync_api.Browser: (
        (
            "close",
            {
                "reason": str,
            },
        ),
        ("new_browser_cdp_session", {}),
        (
            "new_context",
            {
                "accept_downloads": bool,
                "base_url": str,
                "bypass_csp": bool,
                "default_browser_type": str,
                "device_scale_factor": float,
                "has_touch": bool,
                "ignore_https_errors": bool,
                "is_mobile": bool,
                "java_script_enabled": bool,
                "locale": str,
                "no_viewport": bool,
                "offline": bool,
                "record_har_omit_content": bool,
                "record_har_path": str,
                "record_har_url_filter": str,
                "record_video_dir": str,
                "storage_state": str,
                "strict_selectors": bool,
                "timezone_id": str,
                "user_agent": str,
            },
        ),
        (
            "new_page",
            {
                "accept_downloads": bool,
                "base_url": str,
                "bypass_csp": bool,
                "default_browser_type": str,
                "device_scale_factor": float,
                "has_touch": bool,
                "ignore_https_errors": bool,
                "is_mobile": bool,
                "java_script_enabled": bool,
                "locale": str,
                "no_viewport": bool,
                "offline": bool,
                "record_har_omit_content": bool,
                "record_har_path": str,
                "record_har_url_filter": str,
                "record_video_dir": str,
                "storage_state": str,
                "strict_selectors": bool,
                "timezone_id": str,
                "user_agent": str,
            },
        ),
        (
            "start_tracing",
            {
                "path": str,
                "screenshots": bool,
            },
        ),
        ("stop_tracing", {}),
    ),
    playwright.sync_api.Frame: (
        (
            "add_script_tag",
            {
                "content": str,
                "path": str,
                "type": str,
                "url": str,
            },
        ),
        (
            "add_style_tag",
            {
                "content": str,
                "path": str,
                "url": str,
            },
        ),
        (
            "check",
            {
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "click",
            {
                "click_count": int,
                "delay": float,
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        ("content", {}),
        (
            "dblclick",
            {
                "delay": float,
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "dispatch_event",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
                "type": str,
            },
        ),
        (
            "drag_and_drop",
            {
                "force": bool,
                "no_wait_after": bool,
                "source": str,
                "strict": bool,
                "target": str,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "eval_on_selector",
            {
                "expression": str,
                "selector": str,
                "strict": bool,
            },
        ),
        (
            "eval_on_selector_all",
            {
                "expression": str,
                "selector": str,
            },
        ),
        (
            "evaluate",
            {
                "expression": str,
            },
        ),
        (
            "evaluate_handle",
            {
                "expression": str,
            },
        ),
        (
            "fill",
            {
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "value": str,
            },
        ),
        (
            "focus",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        ("frame_element", {}),
        (
            "get_attribute",
            {
                "name": str,
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "goto",
            {
                "referer": str,
                "timeout": float,
                "url": str,
            },
        ),
        (
            "hover",
            {
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "inner_html",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "inner_text",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "input_value",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "is_checked",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "is_disabled",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "is_editable",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "is_enabled",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "is_hidden",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "is_visible",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "press",
            {
                "delay": float,
                "key": str,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "query_selector",
            {
                "selector": str,
                "strict": bool,
            },
        ),
        (
            "query_selector_all",
            {
                "selector": str,
            },
        ),
        (
            "select_option",
            {
                "force": bool,
                "index": int,
                "label": str,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "value": str,
            },
        ),
        (
            "set_checked",
            {
                "checked": bool,
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "set_content",
            {
                "html": str,
                "timeout": float,
            },
        ),
        (
            "set_input_files",
            {
                "files": str,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "tap",
            {
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "text_content",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        ("title", {}),
        (
            "type",
            {
                "delay": float,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "text": str,
                "timeout": float,
            },
        ),
        (
            "uncheck",
            {
                "force": bool,
                "no_wait_after": bool,
                "selector": str,
                "strict": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "wait_for_function",
            {
                "expression": str,
                "polling": float,
                "timeout": float,
            },
        ),
        (
            "wait_for_load_state",
            {
                "timeout": float,
            },
        ),
        (
            "wait_for_selector",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
        (
            "wait_for_timeout",
            {
                "timeout": float,
            },
        ),
        (
            "wait_for_url",
            {
                "timeout": float,
                "url": str,
            },
        ),
    ),
    playwright.sync_api.ElementHandle: (
        ("bounding_box", {}),
        (
            "check",
            {
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "click",
            {
                "click_count": int,
                "delay": float,
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        ("content_frame", {}),
        (
            "dblclick",
            {
                "delay": float,
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "dispatch_event",
            {
                "type": str,
            },
        ),
        ("dispose", {}),
        (
            "eval_on_selector",
            {
                "expression": str,
                "selector": str,
            },
        ),
        (
            "eval_on_selector_all",
            {
                "expression": str,
                "selector": str,
            },
        ),
        (
            "evaluate",
            {
                "expression": str,
            },
        ),
        (
            "evaluate_handle",
            {
                "expression": str,
            },
        ),
        (
            "fill",
            {
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "value": str,
            },
        ),
        ("focus", {}),
        (
            "get_attribute",
            {
                "name": str,
            },
        ),
        ("get_properties", {}),
        (
            "get_property",
            {
                "property_name": str,
            },
        ),
        (
            "hover",
            {
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        ("inner_html", {}),
        ("inner_text", {}),
        (
            "input_value",
            {
                "timeout": float,
            },
        ),
        ("is_checked", {}),
        ("is_disabled", {}),
        ("is_editable", {}),
        ("is_enabled", {}),
        ("is_hidden", {}),
        ("is_visible", {}),
        ("json_value", {}),
        ("owner_frame", {}),
        (
            "press",
            {
                "delay": float,
                "key": str,
                "no_wait_after": bool,
                "timeout": float,
            },
        ),
        (
            "query_selector",
            {
                "selector": str,
            },
        ),
        (
            "query_selector_all",
            {
                "selector": str,
            },
        ),
        (
            "screenshot",
            {
                "mask_color": str,
                "omit_background": bool,
                "path": str,
                "quality": int,
                "style": str,
                "timeout": float,
            },
        ),
        (
            "scroll_into_view_if_needed",
            {
                "timeout": float,
            },
        ),
        (
            "select_option",
            {
                "force": bool,
                "index": int,
                "label": str,
                "no_wait_after": bool,
                "timeout": float,
                "value": str,
            },
        ),
        (
            "select_text",
            {
                "force": bool,
                "timeout": float,
            },
        ),
        (
            "set_checked",
            {
                "checked": bool,
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "set_input_files",
            {
                "files": str,
                "no_wait_after": bool,
                "timeout": float,
            },
        ),
        (
            "tap",
            {
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        ("text_content", {}),
        (
            "type",
            {
                "delay": float,
                "no_wait_after": bool,
                "text": str,
                "timeout": float,
            },
        ),
        (
            "uncheck",
            {
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "wait_for_element_state",
            {
                "timeout": float,
            },
        ),
        (
            "wait_for_selector",
            {
                "selector": str,
                "strict": bool,
                "timeout": float,
            },
        ),
    ),
    playwright.sync_api.Locator: (
        ("all", {}),
        ("all_inner_texts", {}),
        ("all_text_contents", {}),
        (
            "aria_snapshot",
            {
                "ref": bool,
                "timeout": float,
            },
        ),
        (
            "blur",
            {
                "timeout": float,
            },
        ),
        (
            "bounding_box",
            {
                "timeout": float,
            },
        ),
        (
            "check",
            {
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "clear",
            {
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
            },
        ),
        (
            "click",
            {
                "click_count": int,
                "delay": float,
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        ("count", {}),
        (
            "dblclick",
            {
                "delay": float,
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "dispatch_event",
            {
                "timeout": float,
                "type": str,
            },
        ),
        (
            "drag_to",
            {
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "element_handle",
            {
                "timeout": float,
            },
        ),
        ("element_handles", {}),
        (
            "evaluate",
            {
                "expression": str,
                "timeout": float,
            },
        ),
        (
            "evaluate_all",
            {
                "expression": str,
            },
        ),
        (
            "evaluate_handle",
            {
                "expression": str,
                "timeout": float,
            },
        ),
        (
            "fill",
            {
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "value": str,
            },
        ),
        (
            "focus",
            {
                "timeout": float,
            },
        ),
        (
            "get_attribute",
            {
                "name": str,
                "timeout": float,
            },
        ),
        ("highlight", {}),
        (
            "hover",
            {
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "inner_html",
            {
                "timeout": float,
            },
        ),
        (
            "inner_text",
            {
                "timeout": float,
            },
        ),
        (
            "input_value",
            {
                "timeout": float,
            },
        ),
        (
            "is_checked",
            {
                "timeout": float,
            },
        ),
        (
            "is_disabled",
            {
                "timeout": float,
            },
        ),
        (
            "is_editable",
            {
                "timeout": float,
            },
        ),
        (
            "is_enabled",
            {
                "timeout": float,
            },
        ),
        (
            "is_hidden",
            {
                "timeout": float,
            },
        ),
        (
            "is_visible",
            {
                "timeout": float,
            },
        ),
        (
            "press",
            {
                "delay": float,
                "key": str,
                "no_wait_after": bool,
                "timeout": float,
            },
        ),
        (
            "press_sequentially",
            {
                "delay": float,
                "no_wait_after": bool,
                "text": str,
                "timeout": float,
            },
        ),
        (
            "screenshot",
            {
                "mask_color": str,
                "omit_background": bool,
                "path": str,
                "quality": int,
                "style": str,
                "timeout": float,
            },
        ),
        (
            "scroll_into_view_if_needed",
            {
                "timeout": float,
            },
        ),
        (
            "select_option",
            {
                "force": bool,
                "index": int,
                "label": str,
                "no_wait_after": bool,
                "timeout": float,
                "value": str,
            },
        ),
        (
            "select_text",
            {
                "force": bool,
                "timeout": float,
            },
        ),
        (
            "set_checked",
            {
                "checked": bool,
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "set_input_files",
            {
                "files": str,
                "no_wait_after": bool,
                "timeout": float,
            },
        ),
        (
            "tap",
            {
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "text_content",
            {
                "timeout": float,
            },
        ),
        (
            "type",
            {
                "delay": float,
                "no_wait_after": bool,
                "text": str,
                "timeout": float,
            },
        ),
        (
            "uncheck",
            {
                "force": bool,
                "no_wait_after": bool,
                "timeout": float,
                "trial": bool,
            },
        ),
        (
            "wait_for",
            {
                "timeout": float,
            },
        ),
    ),
}
# END:METHODS
